# This file was auto-generated by Fern from our API Definition.

from ....core.api_error import ApiError
from ..types.http_service_unavailable_error_message import HttpServiceUnavailableErrorMessage


class HttpServiceUnavailableError(ApiError):
    def __init__(self, body: HttpServiceUnavailableErrorMessage):
        super().__init__(status_code=503, body=body)
