# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.encounter_patient_control_number_uniqueness_error_type import (
    EncounterPatientControlNumberUniquenessErrorType,
)


class EncounterPatientControlNumberUniquenessError(ApiError):
    def __init__(self, body: EncounterPatientControlNumberUniquenessErrorType):
        super().__init__(status_code=422, body=body)
