# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EmploymentStatus(str, enum.Enum):
    ACTIVE = "ACTIVE"
    TERMINATED = "TERMINATED"

    def visit(self, active: typing.Callable[[], T_Result], terminated: typing.Callable[[], T_Result]) -> T_Result:
        if self is EmploymentStatus.ACTIVE:
            return active()
        if self is EmploymentStatus.TERMINATED:
            return terminated()
