# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClaimSubmissionPayerResponsibilityType(str, enum.Enum):
    PRIMARY = "primary"
    SECONDARY = "secondary"

    def visit(self, primary: typing.Callable[[], T_Result], secondary: typing.Callable[[], T_Result]) -> T_Result:
        if self is ClaimSubmissionPayerResponsibilityType.PRIMARY:
            return primary()
        if self is ClaimSubmissionPayerResponsibilityType.SECONDARY:
            return secondary()
