# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class InsuranceRefundSortField(str, enum.Enum):
    AMOUNT_CENTS = "amount_cents"
    REFUND_TIMESTAMP = "refund_timestamp"
    REFUND_NOTE = "refund_note"
    REFUND_REASON = "refund_reason"

    def visit(
        self,
        amount_cents: typing.Callable[[], T_Result],
        refund_timestamp: typing.Callable[[], T_Result],
        refund_note: typing.Callable[[], T_Result],
        refund_reason: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is InsuranceRefundSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is InsuranceRefundSortField.REFUND_TIMESTAMP:
            return refund_timestamp()
        if self is InsuranceRefundSortField.REFUND_NOTE:
            return refund_note()
        if self is InsuranceRefundSortField.REFUND_REASON:
            return refund_reason()
