# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class WriteOffSortField(str, enum.Enum):
    AMOUNT_CENTS = "amount_cents"
    WRITE_OFF_TIMESTAMP = "write_off_timestamp"
    WRITE_OFF_NOTE = "write_off_note"

    def visit(
        self,
        amount_cents: typing.Callable[[], T_Result],
        write_off_timestamp: typing.Callable[[], T_Result],
        write_off_note: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is WriteOffSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is WriteOffSortField.WRITE_OFF_TIMESTAMP:
            return write_off_timestamp()
        if self is WriteOffSortField.WRITE_OFF_NOTE:
            return write_off_note()
