# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class InvoiceItemUpdateType(str, enum.Enum):
    APPEND = "APPEND"
    OVERWRITE = "OVERWRITE"

    def visit(self, append: typing.Callable[[], T_Result], overwrite: typing.Callable[[], T_Result]) -> T_Result:
        if self is InvoiceItemUpdateType.APPEND:
            return append()
        if self is InvoiceItemUpdateType.OVERWRITE:
            return overwrite()
